"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.collectDevDeps = void 0;
const sortObject_1 = require("./sortObject");
/**
 * Collect all external dev deps for the repo.
 * @param exclude dep names to exclude
 */
function collectDevDeps(workspaceInfo, exclude) {
    var _a;
    const { rootPackageInfo, packageInfos, localPackages } = workspaceInfo;
    const allPackageInfos = [rootPackageInfo, ...Object.values(packageInfos)];
    const allExclude = [...exclude, ...localPackages];
    const devDeps = {};
    for (const packageInfo of allPackageInfos) {
        for (const [depName, version] of Object.entries(packageInfo.devDependencies || {})) {
            if (!allExclude.includes(depName)) {
                devDeps[depName] ?? (devDeps[depName] = {});
                (_a = devDeps[depName])[version] ?? (_a[version] = []);
                devDeps[depName][version].push(packageInfo.name);
            }
        }
    }
    // use sorted order for nicer logging
    return (0, sortObject_1.sortObject)(devDeps);
}
exports.collectDevDeps = collectDevDeps;
